@@ -15,8 +15,6 @@
 #include <cmath>
 #include <qvalidator.h>
 
-// TODO: make divisor a double?
-
 //////////////////////////////////////////////////////////////////////////////
 // Construction, Destruction                                                //
 //////////////////////////////////////////////////////////////////////////////
@@ -26,11 +24,13 @@
 // --------------
 // Constructor
 
-FixedSpinBox::FixedSpinBox(double minValue, double maxValue, double step, unsigned fix,
-    QWidget* parent, const char* name)
-    : QSpinBox(0, 1, 1, parent, name), validator_(0), fixed_(fix), divisor_(0), tinyval_(0)
+FixedSpinBox::FixedSpinBox(double minValue, double maxValue, double step,
+                           unsigned fix, QWidget* parent, const char* name)
+    : QSpinBox(0, 1, 1, parent, name), validator_(0), fixed_(fix), divisor_(0),
+      tinyval_(0)
 {
-    validator_ = new QDoubleValidator(minValue, maxValue, fixed_+1, this, QString(name) + "Validator" );
+    validator_ = new QDoubleValidator(minValue, maxValue, fixed_+1, this,
+                                      QString(name) + "Validator" );
     setValidator(validator_);
     // set the appropriate integers values in the base class
     divisor_ = int(pow(10.0, double(fixed_)));
