@@ -81,7 +81,7 @@ protected:
 private:
     QDoubleValidator* validator_;
     unsigned fixed_;
-    int divisor_;
+    double divisor_;
     double tinyval_;
 };
 
@@ -92,7 +92,7 @@ inline QString FixedSpinBox::mapValueToText(int value)
     { return QString::number(double(value) / divisor_, 'f', fixed_); }
 
 inline int FixedSpinBox::mapTextToValue(bool*)
-    { return int(text().toDouble() * divisor_ + tinyval_); }
+    { return int(cleanText().toDouble() * divisor_ + tinyval_); }
 
 inline double FixedSpinBox::value() const
     { return QSpinBox::value() / double(divisor_); }
