@@ -6,7 +6,7 @@
   begin         October 9th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -39,20 +39,24 @@
 #define GRAIN_H
 
 #include <qlistview.h>
-#include <qmap.h>
 #include <qstring.h>
+#include <qvaluelist.h>
+
+#include "quantity.h"
 
 enum { GRAIN_OTHER, GRAIN_MASHED, GRAIN_STEEPED, GRAIN_EXTRACT };
 
 class Grain {
 public:
+    // default constructor
+    Grain();
     // TODO: get rid of the first (enumerated use) version
     // constructor
-    Grain(const QString &name="grain", const double &quantity=1.0, const double &extract=1.025,
-        const double &color=10.0, const int &use=GRAIN_OTHER);
+    Grain(const QString &name, const Weight &weight, const double &extract,
+          const double &color, const int &use);
     // constructor
-    Grain(const QString &name, const double &quantity, const double &extract,
-        const double &color, const QString &use);
+    Grain(const QString &name, const Weight &quantity, const double &extract,
+          const double &color, const QString &use);
     // copy constructor
     Grain(const Grain &g);
     // assignment operator
@@ -62,14 +66,24 @@ public:
     // destructor
     ~Grain();
 
+    // set name
+    void setName(const QString &name);
     // return name
-    QString name();
-    // return quantity (in pounds)
-    double quantity();
+    QString name() const;
+    // set weight
+    void setWeight(const Weight &weight);
+    // return weight
+    Weight &weight();
+    // set extract
+    void setExtract(double extract);
     // return grain extract
     double extract();
+    // set color
+    void setColor(double color);
     // return grain color
     double color();
+    // set use
+    void setUse(int use);
     // return how grain is used (mash, steep, extract)
     int use();
     // return the yield (quantity times extract)
@@ -77,12 +91,6 @@ public:
     // return the HCU (quantity times color)
     double HCU();
         
-    // return quantity as string
-    QString quantityString();
-    // return extract as string
-    QString extractString();
-    // return color as string
-    QString colorString();
     // return use as string
     QString useString();
 
@@ -91,14 +99,9 @@ public:
     // convert use string to enum
     static int useStringToEnum(const QString &name);
     
-    // return object as string, for serialization (deprecated)
-    QString obsoleteSerializeOut();
-    // set object to string, for serialization (deprecated)
-    void obsoleteSerializeIn(const QString &name, const QString &value);
-    
 private:
     QString name_;
-    double quantity_;
+    Weight weight_;
     double extract_;
     double color_;
     int use_;
@@ -106,15 +109,18 @@ private:
     double hcu_;    // color yield for grain
 };
 
+// TODO map will be more efficient
 typedef QValueList<Grain> GrainList;
 typedef QValueList<Grain>::Iterator GrainIterator;
 
+// TODO: remove this from model
 class GrainListItem : public QListViewItem {
 public:
     // constructor
-    GrainListItem(QListView * parent, QString, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null );
+    GrainListItem(QListView * parent, QString, QString = QString::null,
+                  QString = QString::null, QString = QString::null,
+                  QString = QString::null, QString = QString::null,
+                  QString = QString::null, QString = QString::null );
     // destructor
     ~GrainListItem();
     // get iterator to Grain item
@@ -130,20 +136,26 @@ private:
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
-inline QString Grain::name() { return name_; }
+inline void Grain::setName(const QString &name) { name_ = name; }
 
-inline double Grain::quantity() { return quantity_; }
+inline QString Grain::name() const { return name_; }
+
+inline void Grain::setWeight(const Weight &weight) { weight_ = weight; }
+
+inline Weight& Grain::weight() { return weight_; }
+
+inline void Grain::setExtract(double extract) { extract_ = extract; }
 
 inline double Grain::extract() { return extract_; }
 
+inline void Grain::setColor(double color) { color_ = color; }
+
 inline double Grain::color() { return color_; }
 
+inline void Grain::setUse(int use) { use_ = use; }
+
 inline int Grain::use() { return use_; }
 
-inline QString Grain::quantityString() { return QString::number(quantity_, 'f', 2); }
-
-inline QString Grain::extractString() { return QString::number(extract_, 'f', 3); }
-
 inline double Grain::yield() { return yield_; }
 
 inline double Grain::HCU() { return hcu_; }
