@@ -6,25 +6,25 @@
   begin         October 10th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include "resource.h"
-#include "grainpage.h"
-
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlistview.h>
 #include <qpushbutton.h>
+#include <qstringlist.h>
 
 #include "fixedspinbox.h"
 
-#include "qbrewdoc.h"
-#include "qbrewview.h"
-#include "qbrewcalc.h"
+#include "resource.h"
+#include "model.h"
+#include "view.h"
+
+#include "grainpage.h"
 
 //////////////////////////////////////////////////////////////////////////////
 // Construction, Destruction                                                //
@@ -35,14 +35,16 @@
 // -----------
 // Constructor
 
-GrainPage::GrainPage(QWidget *parent, const char *name, QObject *doc, QObject *calc)
-    : IngredientPage(parent, name, doc, calc), extractlabel_(0), extractspin_(0),
-    colorlabel_(0), colorspin_(0), uselabel_(0), usecombo_(0), currentitem_(0)
+GrainPage::GrainPage(Model *model, View *view, Controller *controller,
+                     const char *name)
+    : IngredientPage(model, view, controller, name), extractlabel_(0),
+      extractspin_(0), colorlabel_(0), colorspin_(0), uselabel_(0),
+      usecombo_(0), currentitem_(0)
 {
     // setup listview
-    itemslistview_->addColumn(tr("Extract"));
-    itemslistview_->addColumn(tr("Color"));
-    itemslistview_->addColumn(tr("Use"));
+    itemslistview_->addColumn("Extract");
+    itemslistview_->addColumn("Color");
+    itemslistview_->addColumn("Use");
     itemslistview_->setColumnAlignment(2, AlignRight);
     itemslistview_->setColumnAlignment(3, AlignRight);
     itemslistview_->setColumnAlignment(4, AlignRight);
@@ -53,13 +55,12 @@ GrainPage::GrainPage(QWidget *parent, const char *name, QObject *doc, QObject *c
     itemslistview_->setSorting(4);
 
     // setup widgets
-    quantityspin_->setSuffix(tr(" lbs"));
-    extractlabel_ = new QLabel(tr("Extract"), this, "extractlabel_");
+    extractlabel_ = new QLabel("Extract", this, "extractlabel_");
     extractspin_ = new FixedSpinBox(1.000, 1.100, 0.001, 3, this, "extractspin_");
-    colorlabel_ = new QLabel(tr("Color"), this, "colorlabel_");
+    colorlabel_ = new QLabel("Color", this, "colorlabel_");
     colorspin_ = new FixedSpinBox(0.0, 500.0, 1.0, 1, this, "colorspin_");
     colorspin_->setSuffix(AppResource::CHAR_LATIN_DEGREE);
-    uselabel_ = new QLabel(tr("Use"), this, "uselabel_");
+    uselabel_ = new QLabel("Use", this, "uselabel_");
     usecombo_ = new QComboBox(false, this, "usecombo_");
     usecombo_->insertStringList(Grain::useStringList());
 
@@ -90,13 +91,15 @@ GrainPage::GrainPage(QWidget *parent, const char *name, QObject *doc, QObject *c
     QWidget::setTabOrder(colorspin_, usecombo_);
 
     // setup connections
-    connect(itemcombo_,SIGNAL(activated(const QString &)), this, SLOT(slotUpdateEntryItems(const QString &)));
-    connect(addbutton_, SIGNAL(clicked()), SLOT(slotAddGrain()));
-    connect(applybutton_, SIGNAL(clicked()), SLOT(slotApplyGrain()));
-    connect(removebutton_, SIGNAL(clicked()), SLOT(slotRemoveGrain()));
-    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)), SLOT(slotItemSelected(QListViewItem *)));
+    connect(itemcombo_, SIGNAL(activated(const QString &)),
+            this, SLOT(updateEntryItems(const QString &)));
+    connect(addbutton_, SIGNAL(clicked()), SLOT(addGrain()));
+    connect(applybutton_, SIGNAL(clicked()), SLOT(applyGrain()));
+    connect(removebutton_, SIGNAL(clicked()), SLOT(removeGrain()));
+    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)),
+            SLOT(itemSelected(QListViewItem *)));
 
-    slotDocumentChanged();
+    documentChanged();
 }
 
 GrainPage::~GrainPage() {}
@@ -106,101 +109,123 @@ GrainPage::~GrainPage() {}
 //////////////////////////////////////////////////////////////////////////////
 
 //////////////////////////////////////////////////////////////////////////////
-// slotUpdateEntryItems()
-// ----------------------
-// Received to update the items in the entry area
+// updateEntryItems()
+// ------------------
+// Update the items in the entry area
 
-void GrainPage::slotUpdateEntryItems(const QString &name)
+void GrainPage::updateEntryItems(const QString &name)
 {
-    Grain *thisgrain = ((QBrewCalc *)calc_)->grain(name);
-    quantityspin_->setValue(thisgrain->quantity());
+    Grain *thisgrain = model_->grain(name);
+    quantityspin_->setValue(thisgrain->weight().amount());
+    quantityspin_->setSuffix(" " + thisgrain->weight().unit().symbol());
     extractspin_->setValue(thisgrain->extract());
     colorspin_->setValue(thisgrain->color());
     // vary default use according to recipe type
     int utemp = thisgrain->use();
     QString ustr = thisgrain->useString();
-    if (((QBrewDoc *)document_)->mash()) {
-        if (utemp == GRAIN_STEEPED) ustr = tr("mashed");
+    if (model_->recipe()->mashed()) {
+        if (utemp == GRAIN_STEEPED) ustr = "mashed";
     } else {
-        if (utemp == GRAIN_MASHED) ustr = tr("steeped");
+        if (utemp == GRAIN_MASHED) ustr = "steeped";
     }
-    setComboItem(usecombo_, ustr);
+    View::setComboItem(usecombo_, ustr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotDocumentChanged()
-// ---------------------
-// Received if document has changed
+// documentChanged()
+// -----------------
+// Document has changed
 
-void GrainPage::slotDocumentChanged()
+void GrainPage::documentChanged()
 {
-    itemcombo_->clear();
-    itemcombo_->insertStringList(((QBrewCalc *)calc_)->grainsList());
-    slotUpdateEntryItems(itemcombo_->currentText());
+    if (itemcombo_->count() == 0) {
+        itemcombo_->clear();
+        itemcombo_->insertStringList(model_->grainsList());
+    }
+    updateEntryItems(itemcombo_->currentText());
     updateListView();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotAddGrain()
-// --------------
-// Received when the user adds a grain to the recipe
+// addGrain()
+// ----------
+// Add a grain to the recipe
 
-void GrainPage::slotAddGrain()
+void GrainPage::addGrain()
 {
     GrainIterator it;
     GrainListItem *item;
-    it = ((QBrewDoc *)document_)->addGrain(itemcombo_->currentText(), quantityspin_->value(),
-        extractspin_->value(), colorspin_->value(), usecombo_->currentText());
-    item = new GrainListItem( itemslistview_, (*it).name(),
-        (*it).quantityString(),
-        (*it).extractString(),
-        (*it).colorString(),
+
+    Grain grain(itemcombo_->currentText(),
+                Weight(quantityspin_->value(), model_->defaultGrainUnit()),
+                extractspin_->value(), colorspin_->value(), 
+                usecombo_->currentText());
+    model_->checkGrain(grain);
+
+    it = model_->recipe()->addGrain(grain);
+    item = new GrainListItem(itemslistview_, (*it).name(),
+        QString::number((*it).weight().amount(), 'f', 2)
+                             + " " + (*it).weight().unit().symbol(),
+        QString::number((*it).extract(), 'f', 3),
+        QString::number((*it).color()) + AppResource::CHAR_LATIN_DEGREE,
         (*it).useString() );
     item->setGrainIterator(it);
+
+    view_->viewModified();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotApplyGrain()
-// ----------------
-// Received when the user applies a grain to the recipe
+// applyGrain()
+// ------------
+// Apply a grain to the recipe
 
-void GrainPage::slotApplyGrain()
-{
-     if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->applyGrain(currentitem_->grainIterator(),
-                itemcombo_->currentText(), quantityspin_->value(), extractspin_->value(),
-                colorspin_->value(), usecombo_->currentText());
-        currentitem_->setToIterator();
-    }
-}
-
-//////////////////////////////////////////////////////////////////////////////
-// slotRemoveGrain()
-// -----------------
-// Received when the user removes a grain from the recipe
-
-void GrainPage::slotRemoveGrain()
+void GrainPage::applyGrain()
 {
     if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->removeGrain(currentitem_->grainIterator());
-        delete currentitem_; currentitem_ = 0;
+        Grain grain(itemcombo_->currentText(),
+                    Weight(quantityspin_->value(), model_->defaultGrainUnit()),
+                    extractspin_->value(), colorspin_->value(), 
+                    usecombo_->currentText());
+        model_->checkGrain(grain);
+
+        model_->recipe()->applyGrain(currentitem_->grainIterator(), grain);
+        currentitem_->setToIterator();
+        view_->viewModified();
     }
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotItemSelected()
-// ------------------
-// Received when a grain is selected in the listview
+// removeGrain()
+// -------------
+// Remove a grain from the recipe
 
-void GrainPage::slotItemSelected(QListViewItem *item)
+void GrainPage::removeGrain()
 {
-    currentitem_ = (GrainListItem *)item;
-    if (item != 0) {
+    if (currentitem_ != 0) {
+        model_->recipe()->removeGrain(currentitem_->grainIterator());
+        delete currentitem_; currentitem_ = 0;
+        view_->viewModified();
+    }
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// itemSelected()
+// --------------
+// A grain is selected in the listview
+
+void GrainPage::itemSelected(QListViewItem *item)
+{
+    if (item) {
+        currentitem_ = dynamic_cast<GrainListItem*>(item);
+        if (currentitem_ == 0) {
+            qWarning("bad dynamic cast, line" + __LINE__);
+            return;
+        }
         itemcombo_->setEditText(item->text(0));
         quantityspin_->setValue(item->text(1).toDouble());
         extractspin_->setValue(item->text(2).toDouble());
         colorspin_->setValue(item->text(3).toDouble());
-        setComboItem(usecombo_, item->text(4));
+        View::setComboItem(usecombo_, item->text(4));
     }
 }
 
@@ -208,26 +233,6 @@ void GrainPage::slotItemSelected(QListViewItem *item)
 // Miscellaneous                                                            //
 //////////////////////////////////////////////////////////////////////////////
 
-//////////////////////////////////////////////////////////////////////////////
-// setComboItem()
-// --------------
-// Set a combo item to the given text
-
-// TODO: this is a duplicate from QBrewView... fix
-void GrainPage::setComboItem(QComboBox *combo, const QString &text)
-{
-    int item;
-    // search combo box for style string
-    for (item = 0; item < combo->count(); item++) {
-        if (combo->text(item) == text) {
-            combo->setCurrentItem(item);
-            return;
-        }
-    }
-    // if item not found, will set it to the first one
-    combo->setCurrentItem(0);
-}
-
 //////////////////////////////////////////////////////////////////////////////
 // updateListView()
 // ----------------
@@ -235,16 +240,18 @@ void GrainPage::setComboItem(QComboBox *combo, const QString &text)
 
 void GrainPage::updateListView()
 {
-    GrainList *list = ((QBrewDoc *)document_)->grainList();
+    GrainList *list = model_->recipe()->grains();
     GrainIterator it;
     GrainListItem *item;
     itemslistview_->clear();
     for (it=list->begin(); it != list->end(); ++it) {
-        item = new GrainListItem( itemslistview_, (*it).name(),
-            (*it).quantityString(),
-            (*it).extractString(),
-            (*it).colorString(),
-            (*it).useString() );
+        item = new GrainListItem(itemslistview_, (*it).name(),
+                                 QString::number((*it).weight().amount(), 'f', 2)
+                                 + " " + (*it).weight().unit().symbol(),
+                                 QString::number((*it).extract(), 'f', 3),
+                                 QString::number((*it).color())
+                                 + AppResource::CHAR_LATIN_DEGREE,
+                                 (*it).useString() );
         item->setGrainIterator(it);
     }
 }
