@@ -6,7 +6,7 @@
   begin         October 10th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -41,29 +41,34 @@
 #include "grain.h"
 #include "ingredientpage.h"
 
+class Model;
 class QCheckBox;
+class View;
 
 class GrainPage : public IngredientPage  {
     Q_OBJECT
 public:
     // constructor
-    GrainPage(QWidget *parent, const char *name, QObject *doc, QObject *calc);
+    GrainPage(Model *model, View *view, Controller *controller,
+              const char *name);
     // destructor
     ~GrainPage();
 
-protected slots:
-    // recieved if add clicked
-    void slotAddGrain();    
-    // recieved if remove clicked
-    void slotRemoveGrain();    
-    // recieved if apply clicked
-    void slotApplyGrain();    
-    // receives if document has changed
-    void slotDocumentChanged();
+public slots:
+    // document has changed
+    void documentChanged();
+
+private slots:
+    // add a grain
+    void addGrain();    
+    // remove a grain
+    void removeGrain();    
+    // apply / change a grain
+    void applyGrain();    
     // update the widgets in the entry area
-    void slotUpdateEntryItems(const QString &name);
-    // received if an ingredient was selected
-    void slotItemSelected(QListViewItem *item);
+    void updateEntryItems(const QString &name);
+    // an ingredient was selected
+    void itemSelected(QListViewItem *item);
 
 private:
     // update the list view
