@@ -6,7 +6,7 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -38,15 +38,22 @@
 #ifndef HOPS_H
 #define HOPS_H
 
-#include <qmap.h>
 #include <qlistview.h>
 #include <qstring.h>
+#include <qvaluelist.h>
+
+#include "quantity.h"
+
+// TODO: use STL
 
 class Hops {
 public:
-    // constructor
-    Hops(const QString &name="hop", const double &quantity=1.0, const QString &form="pellet",
-        const double &alpha=5.0, const unsigned &time=60);
+    // default constructor
+    Hops();
+    // full constructor
+    Hops(const QString &nam, const Weight &weight,
+         const QString &form, const double &alpha,
+         const unsigned &time);
     // copy constructor
     Hops(const Hops &h);
     // assignment operator
@@ -56,50 +63,52 @@ public:
     // destructor
     ~Hops();
 
+    // set name
+    void setName(const QString &name);
     // return name
-    QString name();
-    // return quantity (in ounces)
-    double quantity();
+    QString name() const;
+    // set weight
+    void setWeight(const Weight &weight);
+    // return weight
+    Weight &weight();
+    // set form
+    void setForm(const QString &form);
     // return hops form
     QString form();
+    // set alpha content
+    void setAlpha(double alpha);
     // return hops alpha content
     double alpha();
-    // return boiling time
+    // set boil time
+    void setTime(unsigned time);
+    // return boil time
     unsigned time();
     
     // return precalculated values for bitterness
     double HBU();
-        
-    // return quantity as string
-    QString quantityString();
-    // return alpha as string
-    QString alphaString();
-    // return time as string
-    QString timeString();
-    
-    // return object as string, for serialization (deprecated)
-    QString obsoleteSerializeOut();
-    // set object to string, for serialization (deprecated)
-    void obsoleteSerializeIn(const QString &name, const QString &value);
 
 private:
     QString name_;
-    double quantity_;
+    Weight weight_;
     QString form_;
     double alpha_;
     unsigned time_;
+    // TODO: I don't want hbu here, do I?
     double hbu_;
 };
 
+// TODO: more efficient to use a map
 typedef QValueList<Hops> HopsList;
 typedef QValueList<Hops>::Iterator HopIterator;
 
+// TODO: remove this from the model
 class HopsListItem : public QListViewItem {
 public:
     // constructor
-    HopsListItem(QListView * parent, QString, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null );
+    HopsListItem(QListView * parent, QString, QString = QString::null,
+                 QString = QString::null, QString = QString::null,
+                 QString = QString::null, QString = QString::null,
+                 QString = QString::null, QString = QString::null );
     // destructor
     ~HopsListItem();
     // get iterator to Hop item
@@ -115,22 +124,26 @@ private:
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Operators
 
-inline QString Hops::name() { return name_; }
+inline void Hops::setName(const QString &name) { name_ = name; }
 
-inline double Hops::quantity() { return quantity_; }
+inline QString Hops::name() const { return name_; }
+
+inline void Hops::setWeight(const Weight &weight) { weight_ = weight; }
+
+inline Weight &Hops::weight() { return weight_; }
+
+inline void Hops::setForm(const QString &form) { form_ = form; }
 
 inline QString Hops::form() { return form_; }
 
+inline void Hops::setAlpha(double alpha) { alpha_ = alpha; }
+
 inline double Hops::alpha() { return alpha_; }
 
+inline void Hops::setTime(unsigned time) { time_ = time; }
+
 inline unsigned Hops::time() { return time_; }
 
-inline QString Hops::quantityString() { return QString::number(quantity_, 'f', 2); }
-
-inline QString Hops::alphaString() { return (QString::number(alpha_) + '%'); }
-
-inline QString Hops::timeString() {return QString::number(time_); }
-
 inline double Hops::HBU() { return hbu_; }
 
 inline HopsListItem::~HopsListItem() { ; }
