@@ -6,24 +6,24 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include "hopspage.h"
-
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlistview.h>
 #include <qpushbutton.h>
+#include <qstringlist.h>
 
 #include "fixedspinbox.h"
 
-#include "qbrewdoc.h"
-#include "qbrewview.h"
-#include "qbrewcalc.h"
+#include "model.h"
+#include "view.h"
+
+#include "hopspage.h"
 
 //////////////////////////////////////////////////////////////////////////////
 // Construction, Destruction                                                //
@@ -34,14 +34,16 @@
 // ----------
 // Constructor
 
-HopsPage::HopsPage(QWidget *parent, const char *name, QObject *doc, QObject *calc)
-    : IngredientPage(parent, name, doc, calc), formlabel_(0), formcombo_(0),
-    alphalabel_(0), alphaspin_(0), timelabel_(0), timespin_(0), currentitem_(0)
+HopsPage::HopsPage(Model *model, View *view, Controller *controller,
+                   const char *name)
+    : IngredientPage(model, view, controller, name), formlabel_(0),
+      formcombo_(0), alphalabel_(0), alphaspin_(0), timelabel_(0),
+      timespin_(0), currentitem_(0)
 {
     // setup listview
-    itemslistview_->addColumn(tr("Form"));
-    itemslistview_->addColumn(tr("Alpha"));
-    itemslistview_->addColumn(tr("Time"));
+    itemslistview_->addColumn("Form");
+    itemslistview_->addColumn("Alpha");
+    itemslistview_->addColumn("Time");
     itemslistview_->setColumnAlignment(2, AlignRight);
     itemslistview_->setColumnAlignment(3, AlignRight);
     itemslistview_->setColumnAlignment(4, AlignRight);
@@ -52,16 +54,15 @@ HopsPage::HopsPage(QWidget *parent, const char *name, QObject *doc, QObject *cal
     itemslistview_->setSorting(4);
 
     // setup widgets
-    quantityspin_->setSuffix(tr(" oz"));
-    formlabel_ = new QLabel(tr("Form"), this, "formlabel_");
+    formlabel_ = new QLabel("Form", this, "formlabel_");
     formcombo_ = new QComboBox(true, this, "formcombo_");
-    formcombo_->insertStringList(((QBrewCalc *)calc_)->formsList());
-    alphalabel_ = new QLabel(tr("Alpha"), this, "alphalabel_");
+    formcombo_->insertStringList(model_->formsList());
+    alphalabel_ = new QLabel("Alpha", this, "alphalabel_");
     alphaspin_ = new FixedSpinBox(0.0, 50.0, 0.1, 1, this, "alphaspin_");
     alphaspin_->setSuffix("%");
-    timelabel_ = new QLabel(tr("Time"), this, "timelabel_");
+    timelabel_ = new QLabel("Time", this, "timelabel_");
     timespin_ = new QSpinBox(0, 120, 5, this, "time");
-    timespin_->setSuffix(tr(" min"));
+    timespin_->setSuffix(" min");
 
     // setup layout
     rowtwolayout_->addWidget(quantitylabel_, 0);
@@ -90,13 +91,15 @@ HopsPage::HopsPage(QWidget *parent, const char *name, QObject *doc, QObject *cal
     QWidget::setTabOrder(alphaspin_, timespin_);
 
     // setup connections
-    connect(itemcombo_,SIGNAL(activated(const QString &)), this, SLOT(slotUpdateEntryItems(const QString &)));
-    connect(addbutton_, SIGNAL(clicked()), SLOT(slotAddHops()));
-    connect(applybutton_, SIGNAL(clicked()), SLOT(slotApplyHops()));
-    connect(removebutton_, SIGNAL(clicked()), SLOT(slotRemoveHops()));
-    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)), SLOT(slotItemSelected(QListViewItem *)));
+    connect(itemcombo_, SIGNAL(activated(const QString &)),
+            this, SLOT(updateEntryItems(const QString &)));
+    connect(addbutton_, SIGNAL(clicked()), SLOT(addHops()));
+    connect(applybutton_, SIGNAL(clicked()), SLOT(applyHops()));
+    connect(removebutton_, SIGNAL(clicked()), SLOT(removeHops()));
+    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)),
+            SLOT(itemSelected(QListViewItem *)));
     // initialize widgets with values
-    slotDocumentChanged();
+    documentChanged();
 }
 
 HopsPage::~HopsPage() { ; }
@@ -108,103 +111,114 @@ HopsPage::~HopsPage() { ; }
 //////////////////////////////////////////////////////////////////////////////
 // slotUpdateEntryItems()
 // ----------------------
-// Received to update the hop entry widgets
+// update the hop entry widgets
 
-void HopsPage::slotUpdateEntryItems(const QString &name)
+void HopsPage::updateEntryItems(const QString &name)
 {
-    // highlight the appropriate entry in the listview, if available
-    QListViewItem *item = itemslistview_->firstChild();
-    while (item != 0) {
-        if (item->text(0) == name) {
-            itemslistview_->setSelected(item, true);
-            // this sends the signal selectionChanged()
-            return;
-        }
-        item = item->nextSibling();
-    }
-    // wasn't in the listview, update from database
-    Hops *thisHops = ((QBrewCalc *)calc_)->hop(name);
-    quantityspin_->setValue(thisHops->quantity());
-    formcombo_->setEditText(thisHops->form());
-    alphaspin_->setValue(thisHops->alpha());
-    timespin_->setValue(thisHops->time());
+    Hops *thishop = model_->hop(name);
+    quantityspin_->setValue(thishop->weight().amount());
+    quantityspin_->setSuffix(" " + thishop->weight().unit().symbol());
+    formcombo_->setEditText(thishop->form());
+    alphaspin_->setValue(thishop->alpha());
+    timespin_->setValue(thishop->time());
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotDocumentChanged()
-// ---------------------
-// Received when the document has changed
+// documentChanged()
+// -----------------
+// the document has changed
 
-void HopsPage::slotDocumentChanged()
+void HopsPage::documentChanged()
 {
-    itemcombo_->clear();
-    itemcombo_->insertStringList(((QBrewCalc *)calc_)->hopsList());
-    slotUpdateEntryItems(itemcombo_->currentText());
+    if (itemcombo_->count() == 0) {
+        itemcombo_->clear();
+        itemcombo_->insertStringList(model_->hopsList());
+    }
+    updateEntryItems(itemcombo_->currentText());
     updateListView();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotAddHops()
-// -------------
-// Received when user adds a hop to recipe
+// addHops()
+// ---------
+// Add a hop to recipe
 
-void HopsPage::slotAddHops()
+void HopsPage::addHops()
 {
     HopIterator it;
     HopsListItem *item;
-    it = ((QBrewDoc *)document_)->addHop(itemcombo_->currentText(), quantityspin_->value(),
-        formcombo_->currentText(), alphaspin_->value(), timespin_->value());
-    item = new HopsListItem( itemslistview_, (*it).name(),
-        (*it).quantityString(),
-        (*it).form(),
-        (*it).alphaString(),
-        (*it).timeString() );
+    Hops hop(itemcombo_->currentText(),
+             Weight(quantityspin_->value(), model_->defaultHopsUnit()),
+             formcombo_->currentText(), alphaspin_->value(),
+             timespin_->value());
+    model_->checkHops(hop);
+
+    it = model_->recipe()->addHop(hop);
+    item = new HopsListItem(itemslistview_, (*it).name(),
+                            QString::number((*it).weight().amount(), 'f', 2)
+                            + " " + (*it).weight().unit().symbol(),
+                            (*it).form(),
+                            QString::number((*it).alpha()) + '%',
+                            QString::number((*it).time()) );
     item->setHopIterator(it);
+
+    view_->viewModified();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotApplyHops()
-// ---------------
-// Received when user applies a hop to recipe
+// applyHops()
+// -----------
+// Apply a hop to recipe
 
-void HopsPage::slotApplyHops()
-{
-     if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->applyHop(currentitem_->hopIterator(),
-                itemcombo_->currentText(), quantityspin_->value(),
-                formcombo_->currentText(), alphaspin_->value(), timespin_->value());
-        currentitem_->setToIterator();
-    }
-}
-
-//////////////////////////////////////////////////////////////////////////////
-// slotRemoveHops()
-// ----------------
-// Received when user removes a hop from recipe
-
-void HopsPage::slotRemoveHops()
+void HopsPage::applyHops()
 {
     if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->removeHop(currentitem_->hopIterator());
-        delete currentitem_; currentitem_ = 0;
+        Hops hop(itemcombo_->currentText(),
+             Weight(quantityspin_->value(), model_->defaultHopsUnit()),
+             formcombo_->currentText(), alphaspin_->value(),
+             timespin_->value());
+        model_->checkHops(hop);
+
+        model_->recipe()->applyHop(currentitem_->hopIterator(), hop);
+        currentitem_->setToIterator();
+        view_->viewModified();
     }
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotItemSelected()
+// removeHops()
+// ------------
+// Remove a hop from recipe
+
+void HopsPage::removeHops()
+{
+    if (currentitem_ != 0) {
+        model_->recipe()->removeHop(currentitem_->hopIterator());
+        delete currentitem_; currentitem_ = 0;
+        view_->viewModified();
+    }
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// itemSelected()
 // -----------------
 // Received when user selects an item in listview
 
-void HopsPage::slotItemSelected(QListViewItem *item)
+void HopsPage::itemSelected(QListViewItem *item)
 {
-    currentitem_ = (HopsListItem *)item;
-    if (item != 0) {
+    if (item) {
+        currentitem_ = dynamic_cast<HopsListItem*>(item);
+        if (currentitem_ == 0) {
+            qWarning("bad dynamic cast, line" + __LINE__);
+            return;
+        }
         itemcombo_->setEditText(item->text(0));
         quantityspin_->setValue(item->text(1).toDouble());
         formcombo_->setEditText(item->text(2));
         alphaspin_->setValue(item->text(3).toDouble());
         timespin_->setValue(item->text(4).toUInt());
     }
+
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -218,16 +232,17 @@ void HopsPage::slotItemSelected(QListViewItem *item)
 
 void HopsPage::updateListView()
 {
-    HopsList *list = ((QBrewDoc *)document_)->hopsList();
+    HopsList *list = model_->recipe()->hops();
     HopIterator it;
     HopsListItem *item;
     itemslistview_->clear();
     for (it=list->begin(); it != list->end(); ++it) {
-        item = new HopsListItem( itemslistview_, (*it).name(),
-            (*it).quantityString(),
-            (*it).form(),
-            (*it).alphaString(),
-            (*it).timeString() );
+        item = new HopsListItem(itemslistview_, (*it).name(),
+                                QString::number((*it).weight().amount(), 'f', 2)
+                                + " " + (*it).weight().unit().symbol(),
+                                (*it).form(),
+                                QString::number((*it).alpha()) + '%',
+                                QString::number((*it).time()) );
         item->setHopIterator(it);
     }
 }
