@@ -6,7 +6,7 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -49,23 +49,25 @@ class HopsPage : public IngredientPage  {
    Q_OBJECT
 public: 
     // constructor
-    HopsPage(QWidget *parent, const char *name, QObject *doc, QObject *calc);
+    HopsPage(Model *model, View *view, Controller *controller,
+             const char *name);
     // destructor
     ~HopsPage();
 
-protected slots:
-    // received if add clicked
-    void slotAddHops();    
-    // received if remove clicked
-    void slotRemoveHops();    
-    // received if apply clicked
-    void slotApplyHops();    
-    // receives if document has changed
-    void slotDocumentChanged();
+    // document has changed
+    void documentChanged();
+
+private slots:
+    // add clicked
+    void addHops();    
+    // remove clicked
+    void removeHops();    
+    // apply clicked
+    void applyHops();    
     // update the widgets in the entry area
-    void slotUpdateEntryItems(const QString &name);
-    // received if an ingredient was selected
-    void slotItemSelected(QListViewItem *item);
+    void updateEntryItems(const QString &name);
+    // an ingredient was selected
+    void itemSelected(QListViewItem *item);
 
 private:
     // update the list view
