@@ -6,7 +6,7 @@
   begin         October 8th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -40,24 +40,29 @@
 
 #include <qwidget.h>
 
+class Controller;
 class FixedSpinBox;
+class Model;
 class QBoxLayout;
 class QComboBox;
 class QLabel;
 class QListView;
 class QPushButton;
+class View;
 
 class IngredientPage : public QWidget  {
    Q_OBJECT
 public:
     // constructor
-    IngredientPage(QWidget* parent, const char* name, QObject* doc, QObject* calc);
+    IngredientPage(Model *model, View *view, Controller *controller,
+                   const char* name);
     // destructor
     ~IngredientPage();
-    
+
 protected:
-    QObject* document_;
-    QObject* calc_;
+    Controller *controller_;
+    Model *model_;
+    View *view_;
 
     QBoxLayout* pagelayout_;
     QBoxLayout* rowonelayout_;
@@ -72,7 +77,6 @@ protected:
     QPushButton* applybutton_;
     QPushButton* removebutton_;
     QWidget* spacer_;
-    
 };
 
 #endif // INGREDIENTPAGE_H
