@@ -6,7 +6,7 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
@@ -20,10 +20,30 @@
 // Construction, Destruction                                                //
 //////////////////////////////////////////////////////////////////////////////
 
-MiscIngredient::MiscIngredient(const QString &name, const double &quantity, const QString &notes)
+//////////////////////////////////////////////////////////////////////////////
+// MiscIngredient()
+// ----------------
+// default constructor
+
+MiscIngredient::MiscIngredient()
+    : name_(""), quantity_(), notes_("")
+{ ; }
+
+//////////////////////////////////////////////////////////////////////////////
+// MiscIngredient()
+// ----------------
+// full constructor
+
+MiscIngredient::MiscIngredient(const QString &name, const Quantity &quantity,
+                               const QString &notes)
     : name_(name), quantity_(quantity), notes_(notes)
 { ; }
 
+//////////////////////////////////////////////////////////////////////////////
+// MiscIngredient()
+// ----------------
+// copy constructor
+
 MiscIngredient::MiscIngredient(const MiscIngredient &m)
     : name_(m.name_), quantity_(m.quantity_), notes_(m.notes_)
 { ; }
@@ -51,43 +71,6 @@ bool MiscIngredient::operator==(const MiscIngredient &m)
         && (notes_ == m.notes_);
 }
 
-//////////////////////////////////////////////////////////////////////////////
-// Serialization (deprecated)                                               //
-//////////////////////////////////////////////////////////////////////////////
-
-QString MiscIngredient::obsoleteSerializeOut()
-{
-    // converting to deprecated file format on the fly...
-    return QString::number(quantity_ * 100.0) + ", " + notes_;
-}
-
-void MiscIngredient::obsoleteSerializeIn(const QString &name, const QString &value)
-{
-    QString valuestring = value;
-    QStringList tokens;
-    int pos;
-
-    // get tokens
-    while (valuestring.length() > 0) {
-        pos = valuestring.find(',');
-        if (pos > 0) {
-            tokens += valuestring.left(pos);
-            valuestring.remove(0, pos+1);
-            valuestring = valuestring.stripWhiteSpace();
-        } else {
-            // get last token
-            tokens += valuestring;
-            valuestring = "";
-        }
-    }
-    // create new misc ingredient
-    // TODO: note that commas in the notes will cause problems
-    name_       = name;
-    // converting to deprecated file format on the fly...
-    quantity_   = tokens[0].toDouble() / 100.0;
-    notes_      = tokens[1];
-}
-
 //////////////////////////////////////////////////////////////////////////////
 // MiscIngredientListItem Class                                             //
 //////////////////////////////////////////////////////////////////////////////
@@ -101,6 +84,6 @@ MiscIngredientListItem::~MiscIngredientListItem() { ; }
 void MiscIngredientListItem::setToIterator()
 {
     setText(0, (*mit_).name());
-    setText(1, (*mit_).quantityString());
+    setText(1, QString::number((*mit_).quantity().amount(), 'f', 2));
     setText(2, (*mit_).notes());
 }
