@@ -6,7 +6,7 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -38,14 +38,21 @@
 #ifndef MISCINGREDIENT_H
 #define MISCINGREDIENT_H
 
-#include <qmap.h>
 #include <qlistview.h>
 #include <qstring.h>
+#include <qvaluelist.h>
+
+#include "quantity.h"
+
+// TODO: use STL
 
 class MiscIngredient {
 public:
+    // default constructor
+    MiscIngredient();
     // full constructor
-    MiscIngredient(const QString &name="misc", const double &quantity=1.0, const QString &notes="");
+    MiscIngredient(const QString &name, const Quantity &quantity,
+                   const QString &notes);
     // copy constructor
     MiscIngredient(const MiscIngredient &m);
     // assignment operator
@@ -55,30 +62,29 @@ public:
     // destructor
     ~MiscIngredient();
 
+    // set name
+    void setName(const QString &name);
     // return name
-    QString name();
-    // return quantity (in ounces)
-    double quantity();
+    QString name() const;
+    // set quantity
+    void setQuantity(const Quantity &quantity);
+    // return quantity
+    Quantity &quantity();
+    // set notes
+    void setNotes(const QString &notes);
     // return MiscIngredient notes
     QString notes();
         
-    // return quantity as string
-    QString quantityString();
-    
-    // return object as string, for serialization (deprecated)
-    QString obsoleteSerializeOut();
-    // set object to string, for serialization (deprecated)
-    void obsoleteSerializeIn(const QString &name, const QString &value);
-
 private:
     QString name_;
-    double quantity_; // measured in pounds
+    Quantity quantity_;
     QString notes_;
 };
 
 typedef QValueList<MiscIngredient> MiscIngredientList;
 typedef QValueList<MiscIngredient>::Iterator MiscIngredientIterator;
 
+// TODO: remove this from the model
 class MiscIngredientListItem : public QListViewItem {
 public:
     // constructor
@@ -100,16 +106,22 @@ private:
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
-inline QString MiscIngredient::name() { return name_; }
+inline void MiscIngredient::setName(const QString &name) { name_ = name; }
 
-inline double MiscIngredient::quantity() { return quantity_; }
+inline QString MiscIngredient::name() const { return name_; }
+
+inline void MiscIngredient::setQuantity(const Quantity &quantity) { quantity_ = quantity; }
+
+inline Quantity &MiscIngredient::quantity() { return quantity_; }
+
+inline void MiscIngredient::setNotes(const QString &notes) { notes_ = notes; }
 
 inline QString MiscIngredient::notes() { return notes_; }
 
-inline QString MiscIngredient::quantityString() { return QString::number(quantity_, 'f', 2); }
+inline MiscIngredientIterator MiscIngredientListItem::miscIngredientIterator()
+    { return mit_; }
 
-inline MiscIngredientIterator MiscIngredientListItem::miscIngredientIterator() { return mit_; }
-
-inline void MiscIngredientListItem::setMiscIngredientIterator(MiscIngredientIterator &it) { mit_ = it; }
+inline void MiscIngredientListItem::setMiscIngredientIterator(MiscIngredientIterator &it)
+    { mit_ = it; }
 
 #endif // MISCINGREDIENT_H
