@@ -6,12 +6,10 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include "miscpage.h"
-
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
@@ -19,12 +17,14 @@
 #include <qlineedit.h>
 #include <qlistview.h>
 #include <qpushbutton.h>
+#include <qstringlist.h>
 
 #include "fixedspinbox.h"
 
-#include "qbrewview.h"
-#include "qbrewcalc.h"
-#include "qbrewdoc.h"
+#include "model.h"
+#include "view.h"
+
+#include "miscpage.h"
 
 //////////////////////////////////////////////////////////////////////////////
 // Construction, Destruction                                                //
@@ -35,19 +35,20 @@
 // ----------
 // Constructor
 
-MiscPage::MiscPage(QWidget *parent, const char *name, QObject *doc, QObject *calc)
-    : IngredientPage(parent, name, doc, calc), noteslabel_(0), notesedit_(0), currentitem_(0)
+MiscPage::MiscPage(Model *model, View *view, Controller *controller,
+                   const char *name)
+    : IngredientPage(model, view, controller, name), noteslabel_(0),
+      notesedit_(0), currentitem_(0)
 {
     // setup listview
-    itemslistview_->addColumn(tr("Notes"));
+    itemslistview_->addColumn("Notes");
     itemslistview_->setColumnAlignment(2, AlignLeft);
     itemslistview_->setSorting(0);
     itemslistview_->setSorting(1);
     itemslistview_->setSorting(2);
 
     // setup widgets
-    quantityspin_->setSuffix(tr(" units"));
-    noteslabel_ = new QLabel(tr("Notes"), this, "noteslabel_");
+    noteslabel_ = new QLabel("Notes", this, "noteslabel_");
     notesedit_ = new QLineEdit(this, "notesedit_");
 
     // setup layout
@@ -71,13 +72,16 @@ MiscPage::MiscPage(QWidget *parent, const char *name, QObject *doc, QObject *cal
     QWidget::setTabOrder(quantityspin_, notesedit_);
 
     // setup connections
-    connect(itemcombo_,SIGNAL(activated(const QString &)), this, SLOT(slotUpdateEntryItems(const QString &)));
-    connect(addbutton_, SIGNAL(clicked()), SLOT(slotAddMiscIngredient()));
-    connect(applybutton_, SIGNAL(clicked()), SLOT(slotApplyMiscIngredient()));
-    connect(removebutton_, SIGNAL(clicked()), SLOT(slotRemoveMiscIngredient()));
-    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)), SLOT(slotItemSelected(QListViewItem *)));
+    connect(itemcombo_, SIGNAL(activated(const QString &)),
+            this, SLOT(updateEntryItems(const QString &)));
+    connect(addbutton_, SIGNAL(clicked()), SLOT(addMiscIngredient()));
+    connect(applybutton_, SIGNAL(clicked()), SLOT(applyMiscIngredient()));
+    connect(removebutton_, SIGNAL(clicked()), SLOT(removeMiscIngredient()));
+    connect(itemslistview_, SIGNAL(selectionChanged(QListViewItem *)),
+            SLOT(itemSelected(QListViewItem *)));
+
     // initialize widgets with values
-    slotDocumentChanged();
+    documentChanged();
 }
 
 MiscPage::~MiscPage() { ; }
@@ -87,96 +91,107 @@ MiscPage::~MiscPage() { ; }
 //////////////////////////////////////////////////////////////////////////////
 
 //////////////////////////////////////////////////////////////////////////////
-// slotUpdateEntryItems()
-// ----------------------
-// Received to update the misc ingredient entry widgets
+// updateEntryItems()
+// ------------------
+// update the misc ingredient entry widgets
 
-void MiscPage::slotUpdateEntryItems(const QString &name)
+void MiscPage::updateEntryItems(const QString &name)
 {
-    // highlight the appropriate entry in the listview, if available
-    QListViewItem *item = itemslistview_->firstChild();
-    while (item != 0) {
-        if (item->text(0) == name) {
-            itemslistview_->setSelected(item, true);
-            // this sends the signal selectionChanged()
-            return;
-        }
-        item = item->nextSibling();
-    }
-    // wasn't in the listview, update from database
-    MiscIngredient *thisMiscIngredient = ((QBrewCalc *)calc_)->misc(name);
-    quantityspin_->setValue(thisMiscIngredient->quantity());
-    notesedit_->setText(thisMiscIngredient->notes());
+    MiscIngredient *thismisc = model_->misc(name);
+    quantityspin_->setValue(thismisc->quantity().amount());
+    quantityspin_->setSuffix(" " + thismisc->quantity().unit().symbol());
+    notesedit_->setText(thismisc->notes());
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotDocumentChanged()
-// ---------------------
+// documentChanged()
+// -----------------
 // Received when document has changed
 
-void MiscPage::slotDocumentChanged()
+void MiscPage::documentChanged()
 {
-    itemcombo_->clear();
-    itemcombo_->insertStringList(((QBrewCalc *)calc_)->miscList());
-    slotUpdateEntryItems(itemcombo_->currentText());
+    if (itemcombo_->count() == 0) {
+        itemcombo_->clear();
+        itemcombo_->insertStringList(model_->miscList());
+    }
+    updateEntryItems(itemcombo_->currentText());
     updateListView();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotAddMiscIngredient()
+// addMiscIngredient()
 // -----------------------
-// Received when user adds a misc ingredient to recipe
+// adds a misc ingredient to recipe
 
-void MiscPage::slotAddMiscIngredient()
+void MiscPage::addMiscIngredient()
 {
     MiscIngredientIterator it;
     MiscIngredientListItem *item;
-    it = ((QBrewDoc *)document_)->addMiscIngredient(itemcombo_->currentText(), quantityspin_->value(),
-        notesedit_->text());
-    item = new MiscIngredientListItem( itemslistview_, (*it).name(),
-        (*it).quantityString(),
-        (*it).notes() );
+
+    MiscIngredient misc(itemcombo_->currentText(),
+                         Quantity(quantityspin_->value(), model_->defaultMiscUnit()),
+                         notesedit_->text());
+    model_->checkMisc(misc);
+
+    it = model_->recipe()->addMisc(misc);
+    item = new MiscIngredientListItem(itemslistview_, (*it).name(),
+                                      QString::number((*it).quantity().amount(), 'f', 2)
+                                      + " " + (*it).quantity().unit().symbol(),
+                                      (*it).notes() );
     item->setMiscIngredientIterator(it);
+    view_->viewModified();
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotApplyMiscIngredient()
+// applyMiscIngredient()
 // -------------------------
-// Received when user applies a misc ingredient to recipe
+// applies a misc ingredient to recipe
 
-void MiscPage::slotApplyMiscIngredient()
+void MiscPage::applyMiscIngredient()
 {
      if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->applyMiscIngredient(currentitem_->miscIngredientIterator(),
-                itemcombo_->currentText(), quantityspin_->value(), notesedit_->text());
-        currentitem_->setToIterator();
-    }
+         MiscIngredient misc(itemcombo_->currentText(),
+                         Quantity(quantityspin_->value(), model_->defaultMiscUnit()),
+                         notesedit_->text());
+         model_->checkMisc(misc);
+
+         model_->recipe()->applyMisc(currentitem_->miscIngredientIterator(), misc);
+         currentitem_->setToIterator();
+         view_->viewModified();
+     }
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotRemoveMiscIngredient()
+// removeMiscIngredient()
 // --------------------------
-// Received when user removes a misc ingredient from recipe
+// rremoves a misc ingredient from recipe
 
-void MiscPage::slotRemoveMiscIngredient()
+void MiscPage::removeMiscIngredient()
 {
     if (currentitem_ != 0) {
-        ((QBrewDoc *)document_)->removeMiscIngredient(currentitem_->miscIngredientIterator());
+        model_->recipe()->removeMisc(currentitem_->miscIngredientIterator());
         delete currentitem_; currentitem_ = 0;
+        view_->viewModified();
     }
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// slotItemSelected()
+// itemSelected()
 // ------------------
 // Received when user selects an item in the list view
 
-void MiscPage::slotItemSelected(QListViewItem *item)
+void MiscPage::itemSelected(QListViewItem *item)
 {
-    currentitem_ = (MiscIngredientListItem *)item;
-    if (item != 0) {
+    if (item) {
+        currentitem_ = dynamic_cast<MiscIngredientListItem*>(item);
+        if (currentitem_ == 0) {
+            qWarning("bad dynamic cast, line" + __LINE__);
+            return;
+        }
         itemcombo_->setEditText(item->text(0));
         quantityspin_->setValue(item->text(1).toDouble());
+        // TODO: using default unit, but item might not be default?
+        quantityspin_->setSuffix(" " + model_->defaultMiscUnit().symbol());
         notesedit_->setText(item->text(2));
     }
 }
@@ -192,14 +207,15 @@ void MiscPage::slotItemSelected(QListViewItem *item)
 
 void MiscPage::updateListView()
 {
-    MiscIngredientList *list = ((QBrewDoc *)document_)->miscIngredientList();
+    MiscIngredientList *list = model_->recipe()->miscs();
     MiscIngredientIterator it;
     MiscIngredientListItem *item;
     itemslistview_->clear();
     for (it=list->begin(); it != list->end(); ++it) {
-        item = new MiscIngredientListItem( itemslistview_, (*it).name(),
-            (*it).quantityString(),
-            (*it).notes() );
+        item = new MiscIngredientListItem(itemslistview_, (*it).name(),
+                   QString::number((*it).quantity().amount(), 'f', 2)
+                   + " " + (*it).quantity().unit().symbol(),
+                   (*it).notes() );
         item->setMiscIngredientIterator(it);
     }
 }
