@@ -6,7 +6,7 @@
   begin         October 20th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -47,23 +47,26 @@ class MiscPage : public IngredientPage  {
    Q_OBJECT
 public:
     // constructor
-    MiscPage(QWidget *parent, const char *name, QObject *doc, QObject *calc);
+    MiscPage(Model *model, View *view, Controller *controller,
+             const char *name);
     // destructor
     ~MiscPage();
 
-protected slots:
-    // received if add clicked
-    void slotAddMiscIngredient();    
-    // received if remove clicked
-    void slotRemoveMiscIngredient();    
-    // received if apply clicked
-    void slotApplyMiscIngredient();    
-    // receives if document has changed
-    void slotDocumentChanged();
+public slots:
+    // document has changed
+    void documentChanged();
+
+private slots:
+    // add clicked
+    void addMiscIngredient();    
+    // apply clicked
+    void applyMiscIngredient();    
+    // remove clicked
+    void removeMiscIngredient();    
     // update the widgets in the entry area
-    void slotUpdateEntryItems(const QString &name);
-    // received if an ingredient was selected
-    void slotItemSelected(QListViewItem *item);
+    void updateEntryItems(const QString &name);
+    // an ingredient was selected
+    void itemSelected(QListViewItem *item);
 
 private:
     // update the list view
