@@ -6,7 +6,7 @@
   begin         September 26th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
@@ -22,11 +22,11 @@
 // -------
 // Constructor
 
-Style::Style(const double &oglow, const double &oghi,
-            const double &ibulow, const double &ibuhi,
-            const double &srmlow, const double &srmhi)
-    : OGlow_(oglow), OGhi_(oghi), IBUlow_(ibulow),
-    IBUhi_(ibuhi), SRMlow_(srmlow), SRMhi_(srmhi)
+Style::Style(const QString name, const double &oglow, const double &oghi,
+             const double &ibulow, const double &ibuhi, const double &srmlow,
+             const double &srmhi)
+    : name_(name), oglow_(oglow), oghi_(oghi), ibulow_(ibulow),
+      ibuhi_(ibuhi), srmlow_(srmlow), srmhi_(srmhi)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -35,14 +35,14 @@ Style::Style(const double &oglow, const double &oghi,
 // Copy onstructor
 
 Style::Style(const Style &s)
-    : OGlow_(s.OGlow_), OGhi_(s.OGhi_), IBUlow_(s.IBUlow_),
-    IBUhi_(s.IBUhi_), SRMlow_(s.SRMlow_), SRMhi_(s.SRMhi_)
+    : name_(s.name_), oglow_(s.oglow_), oghi_(s.oghi_), ibulow_(s.ibulow_),
+      ibuhi_(s.ibuhi_), srmlow_(s.srmlow_), srmhi_(s.srmhi_)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
 // ~Style()
 // --------
-// Destrutor
+// Destructor
 
 Style::~Style() {}
 
@@ -58,42 +58,26 @@ Style::~Style() {}
 Style Style::operator=(const Style &s)
 {
     if (&s != this) {
-        OGlow_ = s.OGlow_; OGhi_ = s.OGhi_;
-        IBUlow_ = s.IBUlow_; IBUhi_ = s.IBUhi_;
-        SRMlow_ = s.SRMlow_; SRMhi_ = s.SRMhi_;
+        name_ = s.name_;
+        oglow_ = s.oglow_; oghi_ = s.oghi_;
+        ibulow_ = s.ibulow_; ibuhi_ = s.ibuhi_;
+        srmlow_ = s.srmlow_; srmhi_ = s.srmhi_;
     }
     return *this;
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// obsoleteSerializeIn()
-// ---------------------
-// Serialize the style in from a string, deprecated...
+// operator==
+// ----------
+// Equivalence operator
 
-void Style::obsoleteSerializeIn(const QString &s)
+bool Style::operator==(const Style &s) const
 {
-    QString value = s;
-    QStringList tokens;
-    int pos;
-
-    // get tokens
-    while (value.length() > 0) {
-        pos = value.find(',');
-        if (pos > 0) {
-            tokens += value.left(pos);
-            value.remove(0, pos+1);
-            value = value.stripWhiteSpace();
-        } else {
-            // get last token
-            tokens += value;
-            value = "";
-        }
-    }
-    // create new style
-    OGlow_    = tokens[0].toDouble() / 1000.0 + 1.000;
-    OGhi_    = tokens[1].toDouble() / 1000.0 + 1.000;
-    IBUlow_    = tokens[2].toDouble();
-    IBUhi_    = tokens[3].toDouble();
-    SRMlow_    = tokens[4].toDouble();
-    SRMhi_    = tokens[5].toDouble();
+    return ( (name_ == s.name_) &&
+             (oglow_ == s.oglow_) &&
+             (oghi_ == s.oghi_) &&
+             (ibulow_ == s.ibulow_) &&
+             (ibuhi_ == s.ibuhi_) &&
+             (srmlow_ == s.srmlow_) &&
+             (srmhi_ == s.srmhi_) );
 }
