@@ -6,7 +6,7 @@
   begin         September 26th, 1999
   author        David Johnson <david@usermode.org>
   -------------------
-  Copyright 1999, 2001, David Johnson
+  Copyright 1999-2002, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -38,23 +38,28 @@
 #ifndef STYLE_H
 #define STYLE_H
 
-// TODO: should I also store the name of the style?
+#include <qvaluelist.h>
 
 class QString;
 
 class Style {
-public:
+  public:
     // full constructor
-    Style(const double &oglow=0.0, const double &oghi=1.0,
-          const double &ibulow=0.0, const double &ibuhi=100.0,
-          const double &srmlow=0.0, const double &srmhi=40.0);
+    Style(const QString name="Generic Ale", const double &oglow=0.0,
+          const double &oghi=1.0, const double &ibulow=0.0,
+          const double &ibuhi=100.0, const double &srmlow=0.0,
+          const double &srmhi=40.0);
     // copy constructor
     Style(const Style &s);
     // assignment operator
     Style operator=(const Style &s);
+    // equivalence operator
+    bool operator==(const Style &s) const;
     // destructor
     ~Style();
 
+    // return name of style
+    const QString &name();
     // return high end of OG
     double OGHi();
     // return low end of OG
@@ -68,31 +73,34 @@ public:
     // return low end of SRM
     double SRMLow();
     
-    // set object to string, for serialization (deprecated)
-    void obsoleteSerializeIn(const QString &s);
-    
-private:
-    double OGlow_;
-    double OGhi_;
-    double IBUlow_;
-    double IBUhi_;
-    double SRMlow_;
-    double SRMhi_;
+  private:
+    QString name_;
+    double oglow_;
+    double oghi_;
+    double ibulow_;
+    double ibuhi_;
+    double srmlow_;
+    double srmhi_;
 };
 
+typedef QValueList<Style> StyleList;
+typedef QValueList<Style>::Iterator StyleIterator;
+
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
-inline double Style::OGHi() { return OGhi_; }
+inline const QString &Style::name() { return name_; }
 
-inline double Style::OGLow() { return OGlow_; }
+inline double Style::OGHi() { return oghi_; }
 
-inline double Style::IBUHi() { return IBUhi_; }
+inline double Style::OGLow() { return oglow_; }
 
-inline double Style::IBULow() { return IBUlow_; }
+inline double Style::IBUHi() { return ibuhi_; }
 
-inline double Style::SRMHi() { return SRMhi_; }
+inline double Style::IBULow() { return ibulow_; }
 
-inline double Style::SRMLow() { return SRMlow_; }
+inline double Style::SRMHi() { return srmhi_; }
+
+inline double Style::SRMLow() { return srmlow_; }
 
 #endif // STYLE_H
